#!/usr/bin/env python3
#
# Copyright 2021 Graviti. Licensed under MIT License.
#

"""Healthcheck function."""

from tensorbay.healthcheck.healthcheck import healthcheck

__all__ = ["healthcheck"]
